@@ -1,3 +1,5 @@
+use std::borrow::Cow;
+
 use miette::{Result, WrapErr};
 
 use crate::external::Vcs;
@@ -6,11 +8,11 @@ use crate::external::Vcs;
 pub fn get_vcs_coauthors_config<'a>(
     config: &'a dyn Vcs,
     key: &'a str,
-) -> Result<Vec<Option<&'a str>>> {
+) -> Result<Vec<Option<Cow<'a, str>>>> {
     (0..)
         .take_while(|index| has_vcs_coauthor(config, *index))
         .map(|index| get_vcs_coauthor_config(config, key, index))
-        .fold(Ok(Vec::<Option<&'a str>>::new()), |acc, item| {
+        .fold(Ok(Vec::<Option<Cow<'a, str>>>::new()), |acc, item| {
             match (acc, item) {
                 (Err(error), _) | (Ok(_), Err(error)) => Err(error).wrap_err("failed to read "),
                 (Ok(list), Ok(item)) => Ok(vec![list, vec![item]].concat()),
@@ -27,8 +29,10 @@ pub fn has_vcs_coauthor(config: &dyn Vcs, index: i32) -> bool {
 
 pub fn get_vcs_coauthor_config<'a>(
     config: &'a dyn Vcs,
-    key: &str,
+    key: &'a str,
     index: i32,
-) -> Result<Option<&'a str>> {
-    config.get_str(&format!("mit.author.coauthors.{}.{}", index, key))
+) -> Result<Option<Cow<'a, str>>> {
+    config
+        .get_str(&format!("mit.author.coauthors.{}.{}", index, key))
+        .map(|x| x.map(std::convert::Into::into))
 }
